@@ -1,5 +1,5 @@
-from pydantic import BaseModel
-
+from typing import List, Optional
+from pydantic import BaseModel, Field
 
 class FetcherConfig(BaseModel):
     """
@@ -7,8 +7,7 @@ class FetcherConfig(BaseModel):
     Fetch Provider's have their own uniqueue events and configurations.
     Configurations  
     """
-    pass
-
+    fetcher: Optional[str] = Field(None, description="indicates to OPAL client that it should use a custom FetcherProvider to fetch the data")
 
 class FetchEvent(BaseModel):
     """
@@ -30,3 +29,5 @@ class FetchEvent(BaseModel):
     retry: dict = None
 
 
+
+
