@@ -1,7 +1,7 @@
 from opal_common.fetcher.logger import get_logger
 from typing import Type, Optional, Dict
 from .fetch_provider import BaseFetchProvider
-from .providers.http_get_fetch_provider import HttpGetFetchProvider
+from .providers.http_fetch_provider import HttpFetchProvider
 from .events import FetchEvent
 from ..config import opal_common_config
 
@@ -22,7 +22,7 @@ class FetcherRegister:
 
     # Builtin fetchers
     BASIC_CONFIG = {
-        "HttpGetFetchProvider": HttpGetFetchProvider,
+        "HttpFetchProvider": HttpFetchProvider,
     }
 
     def __init__(self, config: Optional[Dict[str, BaseFetchProvider]] = None) -> None:
@@ -34,9 +34,12 @@ class FetcherRegister:
             fetchers = []
             for module_path in opal_common_config.FETCH_PROVIDER_MODULES:
                 try:
-                    fetchers.extend(emport_objects_by_class(module_path, BaseFetchProvider, ["*"]))
+                    providers_to_register = emport_objects_by_class(module_path, BaseFetchProvider, ["*"])
+                    for provider_name, provider_class in providers_to_register:
+                        logger.info(f"Loading FetcherProvider '{provider_name}' found at: {repr(provider_class)}")
+                    fetchers.extend(providers_to_register)
                 except:
-                    logger.exception("Failed to load FetchingProvider module - {module_path}", module_path=module_path)
+                    logger.exception(f"Failed to load FetchingProvider module: {module_path}")
             self._config = {name: fetcher for name,fetcher in fetchers}
         logger.info("Fetcher Register loaded", extra={'config': self._config})
 
