@@ -1,9 +1,10 @@
 import os
+import uuid
 import shutil
 import asyncio
 
 from functools import partial
-from typing import Optional
+from typing import Optional, Generator
 from pathlib import Path
 from tenacity import retry, wait, stop, RetryError
 from git import Repo, GitError, GitCommandError
@@ -11,6 +12,7 @@ from git import Repo, GitError, GitCommandError
 from opal_common.logger import logger
 from opal_common.git.exceptions import GitFailed
 from opal_common.config import opal_common_config
+from opal_common.utils import get_filepaths_with_glob
 
 
 SSH_PREFIX = "ssh://"
@@ -29,9 +31,8 @@ class CloneResult:
     wraps a git.Repo instance but knows if the repo was initialized with a url
     and cloned from a remote repo, or was initialed from a local `.git` repo.
     """
-    def __init__(self, repo: Repo, cloned_from_remote: bool):
+    def __init__(self, repo: Repo):
         self._repo = repo
-        self._cloned_from_remote = cloned_from_remote
 
     @property
     def repo(self) -> Repo:
@@ -40,23 +41,95 @@ class CloneResult:
         """
         return self._repo
 
-    @property
-    def cloned_from_remote(self) -> bool:
+
+class RepoClonePathFinder:
+    """
+    We are cloning the policy repo into a unique random subdirectory of a base path.
+    Args:
+        base_clone_path (str): parent directory for the repoistory clone
+        clone_subdirectory_prefix (str): the prefix for the randomized repository dir, or the dir name itself when `use_fixes_path=true`
+        use_fixed_path (bool): if set, random suffix won't be added to `clone_subdirectory_prefix` (if the path already exists, it would be reused)
+
+    This class knows how to such clones, so we can discard previous ones, but also so
+    that siblings workers (who are not the master who decided where to clone) can also
+    find the current clone by globing the base dir.
+    """
+    def __init__(self, base_clone_path: str, clone_subdirectory_prefix: str, use_fixed_path: bool):
+        if not base_clone_path:
+            raise ValueError("base_clone_path cannot be empty!")
+
+        if not clone_subdirectory_prefix:
+            raise ValueError("clone_subdirectory_prefix cannot be empty!")
+
+        self._base_clone_path = os.path.expanduser(base_clone_path)
+        self._clone_subdirectory_prefix = clone_subdirectory_prefix
+        self._use_fixed_path = use_fixed_path
+
+    def _get_randomized_clone_subdirectories(self) -> Generator[str, None, None]:
         """
-        whether the repo was cloned from remote, or we found a local matching .git repo
+        a generator yielding all the randomized subdirectories of the base clone path
+        that are matching the clone pattern.
+
+        Yields:
+            the next subdirectory matching the pattern
         """
-        return self._cloned_from_remote
+        folders_with_pattern = get_filepaths_with_glob(self._base_clone_path, f"{self._clone_subdirectory_prefix}-*")
+        for folder in folders_with_pattern:
+            yield folder
 
+    def _get_single_existing_random_clone_path(self) -> Optional[str]:
+        """
+        searches for the single randomly-suffixed clone subdirectory in existance.
 
-class RemoteClone(CloneResult):
-    def __init__(self, repo: Repo):
-        super().__init__(repo=repo, cloned_from_remote=True)
+        If found no such subdirectory or if found more than one (multiple matching subdirectories) - will return None.
+        otherwise: will return the single and only clone.
+        """
+        subdirectories = list(self._get_randomized_clone_subdirectories())
+        if len(subdirectories) != 1:
+            return None
+        return subdirectories[0]
 
+    def _generate_randomized_clone_path(self) -> str:
+        folder_name = f"{self._clone_subdirectory_prefix}-{uuid.uuid4().hex}"
+        full_local_repo_path = os.path.join(self._base_clone_path, folder_name)
+        return full_local_repo_path
 
-class LocalClone(CloneResult):
-    def __init__(self, repo: Repo):
-        super().__init__(repo=repo, cloned_from_remote=False)
+    def _get_fixed_clone_path(self) -> str:
+        return os.path.join(self._base_clone_path, self._clone_subdirectory_prefix)
+    
+    def get_clone_path(self) -> Optional[str]:
+        """
+        Get the clone path (fixed or randomized) if it exists
+        """
+        if self._use_fixed_path:
+            fixed_path = self._get_fixed_clone_path()
+            if os.path.exists(fixed_path):
+                return fixed_path
+            else:
+                return None
+        else:
+            return self._get_single_existing_random_clone_path()
 
+    def create_new_clone_path(self) -> str:
+        """
+        If using a fixed path - simply creates it.
+        If using a randomized suffix - 
+            takes the base path from server config and create new folder with unique name for the local clone.
+            The folder name is looks like /<base-path>/<folder-prefix>-<uuid>
+            If such folders already exist they would be removed.
+        """
+        if self._use_fixed_path:
+            # When using fixed path - just use old path without cleanup
+            full_local_repo_path = self._get_fixed_clone_path()
+        else:
+            # Remove old randomized subdirectories
+            for folder in self._get_randomized_clone_subdirectories():
+                logger.warning("Found previous policy repo clone: {folder_name}, removing it to avoid conflicts.", folder_name=folder)
+                shutil.rmtree(folder)
+            full_local_repo_path = self._generate_randomized_clone_path()
+
+        os.makedirs(full_local_repo_path, exist_ok=True)
+        return full_local_repo_path
 
 class RepoCloner:
     """
@@ -111,31 +184,10 @@ class RepoCloner:
             - does not found a cloned repo locally and clones from remote url
             - finds a cloned repo locally and does not clone from remote.
         """
-        logger.info("Cloning repo from '{url}' to '{to_path}'", url=self.url, to_path=self.path)
-        self._discard_previous_local_clone()
+        logger.info("Cloning repo from '{url}' to '{to_path}' (branch: '{branch}')", url=self.url, to_path=self.path, branch=self.branch_name)
         loop = asyncio.get_running_loop()
         return await loop.run_in_executor(None, self._attempt_clone_from_url)
 
-    def _discard_previous_local_clone(self):
-        """
-        inits the repo from local .git or throws GitFailed
-        """
-        git_path = Path(self.path) / Path(".git")
-        if not git_path.exists():
-            return
-
-        dst_path = "{}.old".format(str(Path(self.path)))
-        i = 0
-        while Path(dst_path + str(i)).exists():
-            i += 1
-        dst_path = dst_path + str(i)
-
-        logger.info(f"Repo already exists in '{self.path}', moving previous clone to '{dst_path}'")
-        try:
-            shutil.move(self.path, dst_path)
-        except Exception as e:
-            logger.error(f"could not move previous clone, got error: {e}")
-
     def _attempt_clone_from_url(self) -> CloneResult:
         """
         clones the repo from url or throws GitFailed
@@ -152,7 +204,7 @@ class RepoCloner:
             raise GitFailed(e)
         else:
             logger.info("Clone succeeded", repo_path=self.path)
-            return RemoteClone(repo)
+            return CloneResult(repo)
 
     def _clone(self, env) -> Repo:
         try:
