@@ -26,4 +26,9 @@ class PolicyBundle(BaseSchema):
     old_hash: Optional[str] = Field(None, description="old commit hash (in diff bundles)")
     data_modules: List[DataModule]
     policy_modules: List[RegoModule]
-    deleted_files: Optional[DeletedFiles]
\ No newline at end of file
+    deleted_files: Optional[DeletedFiles]
+
+class PolicyUpdateMessage(BaseModel):
+    old_policy_hash: str
+    new_policy_hash: str
+    changed_directories: List[str]
\ No newline at end of file
